[![Build Status](https://travis-ci.org/ccnmtl/django-quizblock.svg?branch=master)](https://travis-ci.org/ccnmtl/django-quizblock)
[![Coverage Status](https://coveralls.io/repos/github/ccnmtl/django-quizblock/badge.svg?branch=master)](https://coveralls.io/github/ccnmtl/django-quizblock?branch=master)
